pub struct PermissionContext {
domain: Option<PermissionDomain>,
world: Option<Identifier>,
custom_contexts: Vec<PermissionRuleContext>,
}Expand description
Active runtime context used to evaluate permission rules.
Fields
domain: Option<PermissionDomain>world: Option<Identifier>custom_contexts: Vec<PermissionRuleContext>Implementations
Sourceimpl PermissionContext
impl PermissionContext
Sourcepub fn for_world(world: Identifier) -> Self
pub fn for_world(world: Identifier) -> Self
Creates a context for a loaded world and its owning domain.
Sourcepub fn from_rule_context(
rule_context: &PermissionRuleContext,
) -> Result<Self, PermissionRuleContextError>
pub fn from_rule_context( rule_context: &PermissionRuleContext, ) -> Result<Self, PermissionRuleContextError>
Builds the active context represented by one rule-side expression.
World namespaces are Steel domain names, matching command-visible world identifiers.
Errors
Returns an error if a custom context value conflicts with another value.
fn append_rule_context( &mut self, rule_context: &PermissionRuleContext, ) -> Result<(), PermissionRuleContextError>
Sourcepub fn with_custom_context(
self,
key: PermissionContextKey,
value: impl Into<String>,
) -> Result<Self, PermissionRuleContextError>
pub fn with_custom_context( self, key: PermissionContextKey, value: impl Into<String>, ) -> Result<Self, PermissionRuleContextError>
Adds one custom active context.
Errors
Returns an error for an empty value or a conflicting value for the same key.
Sourcepub fn add_custom_context(
&mut self,
key: PermissionContextKey,
value: impl Into<String>,
) -> Result<(), PermissionRuleContextError>
pub fn add_custom_context( &mut self, key: PermissionContextKey, value: impl Into<String>, ) -> Result<(), PermissionRuleContextError>
Adds one custom active context in place.
Errors
Returns an error for an empty value or a conflicting value for the same key.